table.EinfachGruen {
    border: 0.1vh solid #21A428;
    background-color: #EEEEEE;
    width: 100%;
    text-align: left;
    border-collapse: collapse;
}

table.EinfachGruen td,
table.EinfachGruen th {
    border: 0.1vh solid #AAAAAA;
    padding: 0.3vh 0.3vh;
}

table.EinfachGruen tbody td {
    /* font-size: 13px; */
}

table.EinfachGruen tr:nth-child(even) {
    background: #CEF5C5;
}

table.EinfachGruen thead {
    background: #21A428;
    background: -moz-linear-gradient(top, #58bb5e 0%, #37ad3d 66%, #21A428 100%);
    background: -webkit-linear-gradient(top, #58bb5e 0%, #37ad3d 66%, #21A428 100%);
    background: linear-gradient(to bottom, #58bb5e 0%, #37ad3d 66%, #21A428 100%);
    border-bottom: 0.1vh solid #444444;
}

table.EinfachGruen thead th {
    /* font-size: 15px; */
    font-weight: bold;
    color: #FFFFFF;
    border-left: 0.1vh solid #D0E4F5;
}

table.EinfachGruen thead th:first-child {
    border-left: none;
}